@@ -12,7 +12,7 @@ from .bearing import Bearing
 from .point import Point
 
 
-Wind = namedtuple('Wind', ['direction', 'speed'])
+Wind = namedtuple('Wind', ['direction', 'speed', 'relative_direction'])
 
 
 class Boatd(object):
@@ -50,57 +50,14 @@ class Boatd(object):
         content = self.post({'quit': True}, '/')
         print(content)
 
-
-class LegacyBoat(object):
-    '''
-    A boat controlled by boatd. This is the legacy boat interface for backwards
-    compatibility. Deprecated.
-    '''
-
-    def __init__(self, boatd=None):
-        if boatd is None:
-            self.boatd = Boatd()
-        else:
-            self.boatd = boatd
-
-    @property
-    def heading(self):
-        '''Return the current heading of the boat in degrees'''
-        content = self.boatd.get('/boat')
-        return float(content.get('heading'))
-
-    @property
-    def wind(self):
-        '''Return the direction of the wind in degrees'''
-        content = self.boatd.get('/wind')
-        return Wind(content.get('direction'), content.get('speed'))
-
-    @property
-    def position(self):
-        '''Return a tuple in the form `(latitude, longitude)`'''
-        content = self.boatd.get('/boat')
-        return tuple(content.get('position'))
-
     @property
     def version(self):
         '''Return the version of boatd'''
         content = self.boatd.get('/')
         return content.get('boatd').get('version')
 
-    def rudder(self, angle):
-        '''Set the angle of the rudder to be `angle` degrees'''
-        angle = float(angle)
-        request = self.boatd.post({'value': angle}, '/rudder')
-        return request.get('result')
 
-    def sail(self, angle):
-        '''Set the angle of the sail to `angle` degrees'''
-        angle = float(angle)
-        request = self.boatd.post({'value': angle}, '/sail')
-        return request.get('result')
-
-
-class ConvenienceBoat(object):
+class Boat(object):
     '''A boat controlled by boatd'''
 
     def __init__(self, boatd=None):
@@ -111,53 +68,76 @@ class ConvenienceBoat(object):
 
     @property
     def heading(self):
-        '''Return the current heading of the boat in degrees'''
+        '''
+        Return the current heading of the boat in degrees.
+
+        :returns: current bearing
+        :rtype: Bearing
+        '''
         content = self.boatd.get('/boat')
         return Bearing(float(content.get('heading')))
 
     @property
     def wind(self):
-        '''Return the direction of the wind in degrees'''
+        '''
+        Return the direction of the wind in degrees.
+
+        :returns: wind object containing direction bearing and speed
+        :rtype: Wind
+        '''
         content = self.boatd.get('/wind')
-        return Wind(Bearing(content.get('direction')), content.get('speed'))
+        return Wind(
+            Bearing(content.get('direction')) - self.heading,
+            content.get('speed'),
+            Bearing(content.get('direction'))
+        )
+
+    @property
+    def relative_wind(self):
+        '''
+        Return the direction of the wind, relative to the boat's current
+        direction.
+
+        :returns: wind direction bearing in boat coordinates
+        :rtype: Bearing
+        '''
+        return self.wind.direction
 
     @property
     def position(self):
-        '''Return a tuple in the form `(latitude, longitude)`'''
+        '''
+        Return the current position of the boat.
+
+        :returns: current position
+        :rtype: Point
+        '''
         content = self.boatd.get('/boat')
         lat, lon = content.get('position')
         return Point(lat, lon)
 
-    @property
-    def version(self):
-        '''Return the version of boatd'''
-        content = self.boatd.get('/')
-        return content.get('boatd').get('version')
-
     def set_rudder(self, angle):
-        '''Set the angle of the rudder to be `angle` degrees'''
+        '''
+        Set the angle of the rudder to be `angle` degrees.
+
+        :param angle: rudder angle
+        :type angle: float between -90 and 90
+        '''
         angle = float(angle)
         request = self.boatd.post({'value': float(angle)}, '/rudder')
         return request.get('result')
 
     def set_sail(self, angle):
-        '''Set the angle of the sail to `angle` degrees'''
+        '''
+        Set the angle of the sail to `angle` degrees
+
+        :param angle: sail angle
+        :type angle: float between -90 and 90
+        '''
         angle = float(angle)
         request = self.boatd.post({'value': float(angle)}, '/sail')
         return request.get('result')
 
 
-def Boat(convenience=False, *args, **kwargs):
-    '''
-    Return a Boat instance. If ``convenience`` is True, return an instance of
-    ``ConvenienceBoat``, otherwise return ``LegacyBoat``.
-    '''
-    if convenience is True:
-        return ConvenienceBoat(*args, **kwargs)
-    else:
-        return LegacyBoat(*args, **kwargs)
-
-
 class Behaviour(object):
     def __init__(self, boatd=None):
         if boatd is None:
@@ -193,6 +173,41 @@ class Behaviour(object):
         self.start(None)
 
 
+def get_current_waypoints(boatd=None):
+    '''
+    Get the current set of waypoints active from boatd.
+
+    :returns: The current waypoints
+    :rtype: List of Points
+    '''
+
+    if boatd is None:
+        boatd = Boatd()
+
+    content = boatd.get('/waypoints')
+    return [Point(*coords) for coords in content.get('waypoints')]
+
+
+def get_home_position(boatd=None):
+    '''
+    Get the current home position from boatd.
+
+    :returns: The configured home position
+    :rtype: Points
+    '''
+
+    if boatd is None:
+        boatd = Boatd()
+
+    content = boatd.get('/waypoints')
+    home = content.get('home', None)
+    if home is not None:
+        lat, lon = home
+        return Point(lat, lon)
+    else:
+        return None
+
+
 if __name__ == '__main__':
     boat = Boat()
     print(boat.version)
